#
# spec file for package nvme-cli
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nvme-cli
Version:        1.7
Release:        2.1
Summary:        NVM Express user space tools
License:        GPL-2.0-only
Group:          Hardware/Other
Url:            https://github.com/linux-nvme/nvme-cli
Source:         %{name}-%{version}.tar.gz
Patch1:         0001-wdc-Change-device-capability-checking.patch
Patch2:         0002-wdc-Add-additional-device-for-vs-internal-log.patch
Patch3:         0003-generate-new-documentation.patch
Patch4:         0004-Fix-compilation-with-GCC-8.patch
Patch5:         0005-Fix-CFLAGS-parameter.patch
Patch6:         0006-nvme-cli-fix-compilation-with-uint64_t-cast.patch
Patch100:       0100-nvme_fc-auto-connect-scripts.patch
BuildRequires:  libuuid-devel
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libudev)
BuildRequires:  rubygem(asciidoctor)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NVM Express (NVMe) is a direct attached storage interface. The
nvme-cli package contains core management tools with minimal
dependencies.

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch100 -p1

%build
echo %{version} > version
make CFLAGS="%{optflags} -I." PREFIX=%{_prefix} USE_ASCIIDOCTOR=YesPlease %{?_smp_mflags} all

%install
make PREFIX=%{_prefix} DESTDIR=%{buildroot} install-bin install-man %{?_smp_mflags}
install -m 644 -D /dev/null %{buildroot}%{_sysconfdir}/nvme/hostnqn
install -m 644 -D completions/bash-nvme-completion.sh %{buildroot}%{_sysconfdir}/bash_completion.d/nvme
install -m 644 -D nvme-fc-autoconnect/70-nvmefc-autoconnect.rules %{buildroot}%{_udevrulesdir}/70-nvmefc-autoconnect.rules
install -m 644 -D nvme-fc-autoconnect/nvmefc-boot-connections.service %{buildroot}%{_unitdir}/nvmefc-boot-connections.service
install -m 644 -D nvme-fc-autoconnect/nvmefc-connect@.service %{buildroot}%{_unitdir}/nvmefc-connect@.service

%define services nvmefc-boot-connections.service

%pre
%service_add_pre %services

%post
if [ ! -e %{_sysconfdir}/nvme/hostnqn ]; then
	%{_sbindir}/nvme gen-hostnqn > %{_sysconfdir}/nvme/hostnqn
fi
if [ ! -e %{_sysconfdir}/nvme/hostid ]; then
	%{_bindir}/uuidgen > %{_sysconfdir}/nvme/hostid
fi
%service_add_post %services

%preun
%service_del_preun %services nvmefc-connect@.service

%postun
%service_del_postun %services nvmefc-connect@.service

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{_sbindir}/nvme
%{_mandir}/man1/nvme*.1*
%dir %{_sysconfdir}/bash_completion.d/
%{_sysconfdir}/bash_completion.d/nvme
%{_udevrulesdir}/70-nvmefc-autoconnect.rules
%{_unitdir}/nvmefc-boot-connections.service
%{_unitdir}/nvmefc-connect@.service
%dir %{_sysconfdir}/nvme/
%ghost %{_sysconfdir}/nvme/hostnqn
%ghost %{_sysconfdir}/nvme/hostid 

%changelog
* Tue Jan 29 2019 tiwai@suse.de
- Build documents with asciidoctor (bsc#1075764)
* Mon Jan 28 2019 hare@suse.com
- Update to version 1.7:
  * Use tnvmcap register for creating namespace
  * don't execute a command if --dry-run is supplied
  * Remove trailing "\n" so that the output is valid json
  * nvme-cli: remove unnecessary assignments
  * nvme-print.c : fix ns-descs JSON output
  * nvme-cli: fix typo in json_print_list_items
  * nvme-get-property : Add documentation
  * fabrics: write ctrl_loss_tmo to fabrics device on connect
  * fabrics: write keep-alive-timeout to fabrics device on connect
  * nvme-models.c - search for pci.ids
  * nvme-cli add ns write protect feature support
  * nvme-cli: add minimal ana-log page support
  * nvme-cli: add ana-log documentation
  * Fix print format specifier for 64-bit
  * nvme-ana-log: fixup compiler warning in show_ana_log()
  * nvme-vendor: fixup c99 declaration in huawei plugin
  * nvme-discover: sanitize options
  * Fix nvme id namespace struct
  * nvme-cli: make show_registers_cap() static
  * nvme-cli: wdc-plugin mark array static declaration
  * nvme-cli: fix sparse warnings for declaration
  * nvme-cli: don't use unsigned for fd in lnvm-nvme.c
  * nvme-cli: remove always true condition for u8
  * nvme-cli: fix dead-code nvmf log page discovery
  * nvme-cli: code cleanup for passthru() handlers
  * nvme-cli: fix scaandir() return value
  * nvme-cli: netapp plugin handle empty strings
  * nvme-cli: Fix the displayed metadata length value on Big Endian systems.
  * nvme list : fix nvme list output if identify failed on device
  * nvme-cli: use uniform error message for open
  * nvme-cli: fix indentation
  * nvme-cli: make wdc plug-in functions static
  * nvme-cli: mark functions static
  * nvme-cli: make malloc error handling uniform
  * Enlarge local char[] so snprintf(3) can't truncate path.
  * fabrics: make some arguments integers
  * fabrics: don't fail empty discovery log page
  * nvme: commonize subsystems info in a helper
  * fabrics: add disconnect-all command
  * Regen documentation
  * attach-ns : fix segfault for ctrl list wrong input
  * nvme-discover: Retry discovery log if the generation counter changes
  * nvme-ioctl: retrieve log pages in 4k chunks
  * nvme-discover: Re-check generation counter after log page transfer
  * seagate-nvme: fixup coding style
  * nvme-cli: Add 'rae' argument to nvme_get_log()
  * nvme-cli: kill nvme_passthru_admin()
  * nvme-cli: print "\n" after nvme list-subsys -o json
  * nvme-cli: tests: fix fw_log test coding style
  * nvme-cli: tests: fix id_ctrl test coding style
  * nvme-cli: tests: fix id_ns test coding style
  * nvme-cli: tests: Add get_id_ctrl function
  * Update gitignore for generated test files
  * Add PCI device id checking for the WDC plugin commands.
  * Fix nvme test device selection to use controller value defined in the config.json file. Before this fix, the value was hard coded to nvme0.
  * nvme-cli: prevent resv action field overflow
  * nvme-cli: report subsystem-reset not supported by controller
  * nvme-cli: fix indentation for dir_[send/receive]
  * nvme-cli: make read error handling uniform
  * Use sys/ioctl.h to pull in definitions.
  * Remove unnecessary asm/byteorder.h
  * Remove unnecessary linux/types.h include.
  * Include libgen.h for basename prototype.
  * Include sys/stat.h
  * nvme-cli: remove endian.h
  * We don't need to include linux/types.h here.
  * Initialize line.
  * Use standard interfaces to get timezone offsets.
  * nvme-cli: fix ioctl argument
  * nvme-cli: fix a typo
  * Enable code block syntax highlight in README.md
  * Makefile: fix bash completion install path
  * NVMe-CLI WDC Plugin - Simplify the device id checking routines.
  * nvme-cli: Add wdc-plugin command vs-internal-log and update wdc-plug cap-diag command with transfer-size parameter.
  * nvme-cli: Add help text for wdc-plugin command vs-internal-log. Update help text for wdc-plugin command cap-diag.
  * Update documentation
  * nvme.spec.in : fix bash completion path, require
  * nvme-cli wdc plugin: Add get pfail dump command.
  * nvme-cli wdc plugin: Add documentation for pfail dump.
  * Re-gen documentation for new files
  * wdc: Fix strncpy warning
  * Refactor plugins in a file hierarchy
  * nvme-cli: fix sanitize status endianness
  * nvme-cli: fix ana-log endianness
  * wdc: Use const string for suffix
  * nvme-cli:fix a typo in SELF-TEST log
  * nvme-cli: fix a typo
  * nvme-cli: fix array len to hold string of size 4
  * nvme-cli: fix endianness for the structure field
  * nvme: Handle supported capabilities result for get features
  * connect-all: special treatment to EALREADY afetr write to /dev/nvme-fabrics
  * Added zsh completion installation
  * nvme-cli: fix a typo
  * nvme: fixup ANA group descriptor offset
  * nvme: introduce get_nvme_ctrl_attr()
  * nvme: print out controller state for 'list-subsys'
  * nvme-list-subsys: Add device name argument and print out ANA state
  * list-subsys: Preserve line breaks and spaces
  * Regen documentation
  * In json output, if the commands add zero length string, it occur allocation fail & abort (cannot display empty value)
  * Fix printing of large ANAGRPID values
  * micron-nvme: Replace direct use of ioctl
  * Fix printing of large ANAGRPID values
  * Fix typos in docs
  * Fix typos in tests and utils
  * fabrics: support fabrics sq flow control disable
  * fabrics: use trtype_str when parsing a discovery log entry
  * nvme: Add TCP transport
  * fabrics: add tcp port tsas decoding
  * fabrics: add transport header and data digest
  * nvme-ioctl: clear rae for discovery log pages
  * Added support for virtualization-management command
  * nvme-cli: Don't print result on passthru error
  * nvme-cli: readme: fix typo in Alpine distro support
  * Added gentoo to README.md
  * fabrics: pass in number of write queues
  * fabrics: pass in number of polling queues
  * Update documentation
  * README: update Arch Linux install instructions
  * fabrics: allow nr_io/write/poll_queues and queue size to discovery
  * nvme: Adding a block size selector to format
  * nvme: Regenerate documentation
  * timeout option added to ns_create/delete (#440)
  * nvme: Remove duplicate error message
  * rpm spec file: add zsh completion (#447)
  * nvme: Release 1.7
- Drop obsolete patches:
  - 0001-Use-tnvmcap-register-for-creating-namespace.patch
  - 0002-don-t-execute-a-command-if-dry-run-is-supplied.patch
  - 0003-Remove-trailing-n-so-that-the-output-is-valid-json.patch
  - 0004-nvme-cli-remove-unnecessary-assignments.patch
  - 0005-nvme-print.c-fix-ns-descs-JSON-output.patch
  - 0006-nvme-cli-fix-typo-in-json_print_list_items.patch
  - 0007-nvme-get-property-Add-documentation.patch
  - 0008-fabrics-write-ctrl_loss_tmo-to-fabrics-device-on-con.patch
  - 0009-fabrics-write-keep-alive-timeout-to-fabrics-device-o.patch
  - 0010-nvme-models.c-search-for-pci.ids.patch
  - 0011-nvme-cli-add-ns-write-protect-feature-support.patch
  - 0012-nvme-cli-add-minimal-ana-log-page-support.patch
  - 0013-nvme-cli-add-ana-log-documentation.patch
  - 0014-Fix-print-format-specifier-for-64-bit.patch
  - 0015-nvme-ana-log-fixup-compiler-warning-in-show_ana_log.patch
  - 0016-nvme-vendor-fixup-c99-declaration-in-huawei-plugin.patch
  - 0017-nvme-discover-sanitize-options.patch
  - 0018-Fix-nvme-id-namespace-struct.patch
  - 0019-nvme-cli-make-show_registers_cap-static.patch
  - 0020-nvme-cli-wdc-plugin-mark-array-static-declaration.patch
  - 0021-nvme-cli-fix-sparse-warnings-for-declaration.patch
  - 0022-nvme-cli-don-t-use-unsigned-for-fd-in-lnvm-nvme.c.patch
  - 0023-nvme-cli-remove-always-true-condition-for-u8.patch
  - 0024-nvme-cli-fix-dead-code-nvmf-log-page-discovery.patch
  - 0025-nvme-cli-code-cleanup-for-passthru-handlers.patch
  - 0026-nvme-cli-fix-scaandir-return-value.patch
  - 0027-nvme-cli-netapp-plugin-handle-empty-strings.patch
  - 0028-nvme-cli-Fix-the-displayed-metadata-length-value-on-.patch
  - 0029-nvme-list-fix-nvme-list-output-if-identify-failed-on.patch
  - 0030-nvme-cli-use-uniform-error-message-for-open.patch
  - 0031-nvme-cli-fix-indentation.patch
  - 0032-nvme-cli-make-wdc-plug-in-functions-static.patch
  - 0033-nvme-cli-mark-functions-static.patch
  - 0034-nvme-cli-make-malloc-error-handling-uniform.patch
  - 0035-Enlarge-local-char-so-snprintf-3-can-t-truncate-path.patch
  - 0036-fabrics-make-some-arguments-integers.patch
  - 0037-fabrics-don-t-fail-empty-discovery-log-page.patch
  - 0038-nvme-commonize-subsystems-info-in-a-helper.patch
  - 0039-fabrics-add-disconnect-all-command.patch
  - 0040-Regen-documentation.patch
  - 0041-attach-ns-fix-segfault-for-ctrl-list-wrong-input.patch
  - 0042-nvme-discover-Retry-discovery-log-if-the-generation-.patch
  - 0043-nvme-ioctl-retrieve-log-pages-in-4k-chunks.patch
  - 0044-nvme-discover-Re-check-generation-counter-after-log-.patch
  - 0045-seagate-nvme-fixup-coding-style.patch
  - 0046-nvme-cli-Add-rae-argument-to-nvme_get_log.patch
  - 0047-nvme-cli-kill-nvme_passthru_admin.patch
  - 0048-nvme-cli-print-n-after-nvme-list-subsys-o-json.patch
  - 0049-nvme-cli-tests-fix-fw_log-test-coding-style.patch
  - 0050-nvme-cli-tests-fix-id_ctrl-test-coding-style.patch
  - 0051-nvme-cli-tests-fix-id_ns-test-coding-style.patch
  - 0052-nvme-cli-tests-Add-get_id_ctrl-function.patch
  - 0054-Add-PCI-device-id-checking-for-the-WDC-plugin-comman.patch
  - 0055-Fix-nvme-test-device-selection-to-use-controller-val.patch
  - 0056-nvme-cli-prevent-resv-action-field-overflow.patch
  - 0057-nvme-cli-report-subsystem-reset-not-supported-by-con.patch
  - 0058-nvme-cli-fix-indentation-for-dir_-send-receive.patch
  - 0059-nvme-cli-make-read-error-handling-uniform.patch
  - 0060-Use-sys-ioctl.h-to-pull-in-definitions.patch
  - 0061-Remove-unnecessary-asm-byteorder.h.patch
  - 0062-Remove-unnecessary-linux-types.h-include.patch
  - 0063-Include-libgen.h-for-basename-prototype.patch
  - 0064-Include-sys-stat.h.patch
  - 0065-nvme-cli-remove-endian.h.patch
  - 0066-We-don-t-need-to-include-linux-types.h-here.patch
  - 0067-Initialize-line.patch
  - 0068-Use-standard-interfaces-to-get-timezone-offsets.patch
  - 0069-nvme-cli-fix-ioctl-argument.patch
  - 0070-nvme-cli-fix-a-typo.patch
  - 0071-Enable-code-block-syntax-highlight-in-README.md.patch
  - 0072-Makefile-fix-bash-completion-install-path.patch
  - 0073-NVMe-CLI-WDC-Plugin-Simplify-the-device-id-checking-.patch
  - 0074-nvme-cli-Add-wdc-plugin-command-vs-internal-log-and-.patch
  - 0075-nvme-cli-Add-help-text-for-wdc-plugin-command-vs-int.patch
  - 0076-Update-documentation.patch
  - 0077-nvme.spec.in-fix-bash-completion-path-require.patch
  - 0078-nvme-cli-wdc-plugin-Add-get-pfail-dump-command.patch
  - 0079-nvme-cli-wdc-plugin-Add-documentation-for-pfail-dump.patch
  - 0080-Re-gen-documentation-for-new-files.patch
  - 0081-wdc-Fix-strncpy-warning.patch
  - 0082-Refactor-plugins-in-a-file-hierarchy.patch
  - 0083-nvme-cli-fix-sanitize-status-endianness.patch
  - 0084-nvme-cli-fix-ana-log-endianness.patch
  - 0085-wdc-Use-const-string-for-suffix.patch
  - 0086-nvme-cli-fix-a-typo-in-SELF-TEST-log.patch
  - 0087-nvme-cli-fix-a-typo.patch
  - 0088-nvme-cli-fix-array-len-to-hold-string-of-size-4.patch
  - 0089-nvme-cli-fix-endianness-for-the-structure-field.patch
  - 0090-nvme-Handle-supported-capabilities-result-for-get-fe.patch
  - 0091-connect-all-special-treatment-to-EALREADY-afetr-writ.patch
  - 0092-Added-zsh-completion-installation.patch
  - 0093-nvme-cli-fix-a-typo.patch
  - 0094-nvme-fixup-ANA-group-descriptor-offset.patch
  - 0095-nvme-introduce-get_nvme_ctrl_attr.patch
  - 0096-nvme-print-out-controller-state-for-list-subsys.patch
  - 0097-nvme-list-subsys-Add-device-name-argument-and-print-.patch
  - 0098-list-subsys-Preserve-line-breaks-and-spaces.patch
  - 0099-Regen-documentation.patch
  - 0100-In-json-output-if-the-commands-add-zero-length-strin.patch
  - 0101-Fix-printing-of-large-ANAGRPID-values.patch
  - 0102-micron-nvme-Replace-direct-use-of-ioctl.patch
  - 0104-Fix-typos-in-docs.patch
  - 0105-Fix-typos-in-tests-and-utils.patch
  - 0106-fabrics-support-fabrics-sq-flow-control-disable.patch
  - 0107-fabrics-use-trtype_str-when-parsing-a-discovery-log-.patch
  - 0108-nvme-Add-TCP-transport.patch
  - 0109-fabrics-add-tcp-port-tsas-decoding.patch
  - 0110-fabrics-add-transport-header-and-data-digest.patch
  - 0111-nvme-ioctl-clear-rae-for-discovery-log-pages.patch
  - 0112-Added-support-for-virtualization-management-command.patch
  - 0113-nvme-cli-Don-t-print-result-on-passthru-error.patch
  - 0114-nvme-cli-readme-fix-typo-in-Alpine-distro-support.patch
  - 0115-Added-gentoo-to-README.md.patch
  - 0116-fabrics-pass-in-number-of-write-queues.patch
  - 0117-fabrics-pass-in-number-of-polling-queues.patch
  - 0118-Update-documentation.patch
  - 0119-README-update-Arch-Linux-install-instructions.patch
  - 0120-fabrics-allow-nr_io-write-poll_queues-and-queue-size.patch
  - 0121-nvme-Adding-a-block-size-selector-to-format.patch
  - 0122-nvme-Regenerate-documentation.patch
  - 0123-timeout-option-added-to-ns_create-delete-440.patch
  - 0124-nvme-Remove-duplicate-error-message.patch
- Add patches from upstream git tree (FATE#326925)
  + 0001-wdc-Change-device-capability-checking.patch
  + 0002-wdc-Add-additional-device-for-vs-internal-log.patch
  + 0003-generate-new-documentation.patch
  + 0004-Fix-compilation-with-GCC-8.patch
  + 0005-Fix-CFLAGS-parameter.patch
  + 0006-nvme-cli-fix-compilation-with-uint64_t-cast.patch
- Add FC-NVMe autoconnect scripts (bsc#1103354)
  + 0100-nvme_fc-auto-connect-scripts.patch
* Thu Jan 10 2019 hare@suse.de
- Use tnvmcap register for creating namespace (FATE#326925)
  + 0001-Use-tnvmcap-register-for-creating-namespace.patch
- don't execute a command if --dry-run is supplied (FATE#326925)
  + 0002-don-t-execute-a-command-if-dry-run-is-supplied.patch
- Remove trailing "\n" so that the output is valid json (FATE#326925)
  + 0003-Remove-trailing-n-so-that-the-output-is-valid-json.patch
- nvme-cli: remove unnecessary assignments (FATE#326925)
  + 0004-nvme-cli-remove-unnecessary-assignments.patch
- nvme-print.c : fix ns-descs JSON output (FATE#326925)
  + 0005-nvme-print.c-fix-ns-descs-JSON-output.patch
- nvme-cli: fix typo in json_print_list_items (FATE#326925)
  + 0006-nvme-cli-fix-typo-in-json_print_list_items.patch
- nvme-get-property : Add documentation (FATE#326925)
  + 0007-nvme-get-property-Add-documentation.patch
- fabrics: write ctrl_loss_tmo to fabrics device on connect (FATE#326925)
  + 0008-fabrics-write-ctrl_loss_tmo-to-fabrics-device-on-con.patch
- fabrics: write keep-alive-timeout to fabrics device on (FATE#326925)
  + 0009-fabrics-write-keep-alive-timeout-to-fabrics-device-o.patch
- nvme-models.c - search for pci.ids (FATE#326925)
  + 0010-nvme-models.c-search-for-pci.ids.patch
- nvme-cli add ns write protect feature support (FATE#326925)
  + 0011-nvme-cli-add-ns-write-protect-feature-support.patch
- nvme-cli: add minimal ana-log page support (FATE#326925)
  + 0012-nvme-cli-add-minimal-ana-log-page-support.patch
- nvme-cli: add ana-log documentation (FATE#326925)
  + 0013-nvme-cli-add-ana-log-documentation.patch
- Fix print format specifier for 64-bit (FATE#326925)
  + 0014-Fix-print-format-specifier-for-64-bit.patch
- nvme-ana-log: fixup compiler warning in show_ana_log() (FATE#326925)
  + 0015-nvme-ana-log-fixup-compiler-warning-in-show_ana_log.patch
- nvme-vendor: fixup c99 declaration in huawei plugin (FATE#326925)
  + 0016-nvme-vendor-fixup-c99-declaration-in-huawei-plugin.patch
- nvme-discover: sanitize options (FATE#326925)
  + 0017-nvme-discover-sanitize-options.patch
- Fix nvme id namespace struct (FATE#326925)
  + 0018-Fix-nvme-id-namespace-struct.patch
- nvme-cli: make show_registers_cap() static (FATE#326925)
  + 0019-nvme-cli-make-show_registers_cap-static.patch
- nvme-cli: wdc-plugin mark array static declaration (FATE#326925)
  + 0020-nvme-cli-wdc-plugin-mark-array-static-declaration.patch
- nvme-cli: fix sparse warnings for declaration (FATE#326925)
  + 0021-nvme-cli-fix-sparse-warnings-for-declaration.patch
- nvme-cli: don't use unsigned for fd in lnvm-nvme.c (FATE#326925)
  + 0022-nvme-cli-don-t-use-unsigned-for-fd-in-lnvm-nvme.c.patch
- nvme-cli: remove always true condition for u8 (FATE#326925)
  + 0023-nvme-cli-remove-always-true-condition-for-u8.patch
- nvme-cli: fix dead-code nvmf log page discovery (FATE#326925)
  + 0024-nvme-cli-fix-dead-code-nvmf-log-page-discovery.patch
- nvme-cli: code cleanup for passthru() handlers (FATE#326925)
  + 0025-nvme-cli-code-cleanup-for-passthru-handlers.patch
- nvme-cli: fix scaandir() return value (FATE#326925)
  + 0026-nvme-cli-fix-scaandir-return-value.patch
- nvme-cli: netapp plugin handle empty strings (FATE#326925)
  + 0027-nvme-cli-netapp-plugin-handle-empty-strings.patch
- nvme-cli: Fix the displayed metadata length value on Big (FATE#326925)
  + 0028-nvme-cli-Fix-the-displayed-metadata-length-value-on-.patch
- nvme list : fix nvme list output if identify failed on device (FATE#326925)
  + 0029-nvme-list-fix-nvme-list-output-if-identify-failed-on.patch
- nvme-cli: use uniform error message for open (FATE#326925)
  + 0030-nvme-cli-use-uniform-error-message-for-open.patch
- nvme-cli: use uniform error message for open (FATE#326925)
  + 0030-nvme-cli-use-uniform-error-message-for-open.patch~
- nvme-cli: fix indentation (FATE#326925)
  + 0031-nvme-cli-fix-indentation.patch
- nvme-cli: make wdc plug-in functions static (FATE#326925)
  + 0032-nvme-cli-make-wdc-plug-in-functions-static.patch
- nvme-cli: mark functions static (FATE#326925)
  + 0033-nvme-cli-mark-functions-static.patch
- nvme-cli: make malloc error handling uniform (FATE#326925)
  + 0034-nvme-cli-make-malloc-error-handling-uniform.patch
- Enlarge local char[] so snprintf(3) can't truncate path. (FATE#326925)
  + 0035-Enlarge-local-char-so-snprintf-3-can-t-truncate-path.patch
- fabrics: make some arguments integers (FATE#326925)
  + 0036-fabrics-make-some-arguments-integers.patch
- fabrics: don't fail empty discovery log page (FATE#326925)
  + 0037-fabrics-don-t-fail-empty-discovery-log-page.patch
- nvme: commonize subsystems info in a helper (FATE#326925)
  + 0038-nvme-commonize-subsystems-info-in-a-helper.patch
- fabrics: add disconnect-all command (FATE#326925)
  + 0039-fabrics-add-disconnect-all-command.patch
- Regen documentation (FATE#326925)
  + 0040-Regen-documentation.patch
- attach-ns : fix segfault for ctrl list wrong input (FATE#326925)
  + 0041-attach-ns-fix-segfault-for-ctrl-list-wrong-input.patch
- nvme-discover: Retry discovery log if the generation counter (FATE#326925)
  + 0042-nvme-discover-Retry-discovery-log-if-the-generation-.patch
- nvme-ioctl: retrieve log pages in 4k chunks (FATE#326925)
  + 0043-nvme-ioctl-retrieve-log-pages-in-4k-chunks.patch
- nvme-discover: Re-check generation counter after log page (FATE#326925)
  + 0044-nvme-discover-Re-check-generation-counter-after-log-.patch
- seagate-nvme: fixup coding style (FATE#326925)
  + 0045-seagate-nvme-fixup-coding-style.patch
- nvme-cli: Add 'rae' argument to nvme_get_log() (FATE#326925)
  + 0046-nvme-cli-Add-rae-argument-to-nvme_get_log.patch
- nvme-cli: kill nvme_passthru_admin() (FATE#326925)
  + 0047-nvme-cli-kill-nvme_passthru_admin.patch
- nvme-cli: print "\n" after nvme list-subsys -o json (FATE#326925)
  + 0048-nvme-cli-print-n-after-nvme-list-subsys-o-json.patch
- nvme-cli: tests: fix fw_log test coding style (FATE#326925)
  + 0049-nvme-cli-tests-fix-fw_log-test-coding-style.patch
- nvme-cli: tests: fix id_ctrl test coding style (FATE#326925)
  + 0050-nvme-cli-tests-fix-id_ctrl-test-coding-style.patch
- nvme-cli: tests: fix id_ns test coding style (FATE#326925)
  + 0051-nvme-cli-tests-fix-id_ns-test-coding-style.patch
- nvme-cli: tests: Add get_id_ctrl function (FATE#326925)
  + 0052-nvme-cli-tests-Add-get_id_ctrl-function.patch
- Add PCI device id checking for the WDC plugin commands. (FATE#326925)
  + 0054-Add-PCI-device-id-checking-for-the-WDC-plugin-comman.patch
- Fix nvme test device selection to use controller value (FATE#326925)
  + 0055-Fix-nvme-test-device-selection-to-use-controller-val.patch
- nvme-cli: prevent resv action field overflow (FATE#326925)
  + 0056-nvme-cli-prevent-resv-action-field-overflow.patch
- nvme-cli: report subsystem-reset not supported by controller (FATE#326925)
  + 0057-nvme-cli-report-subsystem-reset-not-supported-by-con.patch
- nvme-cli: fix indentation for dir_[send/receive] (FATE#326925)
  + 0058-nvme-cli-fix-indentation-for-dir_-send-receive.patch
- nvme-cli: make read error handling uniform (FATE#326925)
  + 0059-nvme-cli-make-read-error-handling-uniform.patch
- Use sys/ioctl.h to pull in definitions. (FATE#326925)
  + 0060-Use-sys-ioctl.h-to-pull-in-definitions.patch
- Remove unnecessary asm/byteorder.h (FATE#326925)
  + 0061-Remove-unnecessary-asm-byteorder.h.patch
- Remove unnecessary linux/types.h include. (FATE#326925)
  + 0062-Remove-unnecessary-linux-types.h-include.patch
- Include libgen.h for basename prototype. (FATE#326925)
  + 0063-Include-libgen.h-for-basename-prototype.patch
- Include sys/stat.h (FATE#326925)
  + 0064-Include-sys-stat.h.patch
- nvme-cli: remove endian.h (FATE#326925)
  + 0065-nvme-cli-remove-endian.h.patch
- We don't need to include linux/types.h here. (FATE#326925)
  + 0066-We-don-t-need-to-include-linux-types.h-here.patch
- Initialize line. (FATE#326925)
  + 0067-Initialize-line.patch
- Use standard interfaces to get timezone offsets. (FATE#326925)
  + 0068-Use-standard-interfaces-to-get-timezone-offsets.patch
- nvme-cli: fix ioctl argument (FATE#326925)
  + 0069-nvme-cli-fix-ioctl-argument.patch
- nvme-cli: fix a typo (FATE#326925)
  + 0070-nvme-cli-fix-a-typo.patch
- Enable code block syntax highlight in README.md (FATE#326925)
  + 0071-Enable-code-block-syntax-highlight-in-README.md.patch
- Makefile: fix bash completion install path (FATE#326925)
  + 0072-Makefile-fix-bash-completion-install-path.patch
- NVMe-CLI WDC Plugin - Simplify the device id checking (FATE#326925)
  + 0073-NVMe-CLI-WDC-Plugin-Simplify-the-device-id-checking-.patch
- nvme-cli: Add wdc-plugin command vs-internal-log and update (FATE#326925)
  + 0074-nvme-cli-Add-wdc-plugin-command-vs-internal-log-and-.patch
- nvme-cli: Add help text for wdc-plugin command (FATE#326925)
  + 0075-nvme-cli-Add-help-text-for-wdc-plugin-command-vs-int.patch
- Update documentation (FATE#326925)
  + 0076-Update-documentation.patch
- nvme.spec.in : fix bash completion path, require (FATE#326925)
  + 0077-nvme.spec.in-fix-bash-completion-path-require.patch
- nvme-cli wdc plugin: Add get pfail dump command. (FATE#326925)
  + 0078-nvme-cli-wdc-plugin-Add-get-pfail-dump-command.patch
- nvme-cli wdc plugin: Add documentation for pfail dump. (FATE#326925)
  + 0079-nvme-cli-wdc-plugin-Add-documentation-for-pfail-dump.patch
- Re-gen documentation for new files (FATE#326925)
  + 0080-Re-gen-documentation-for-new-files.patch
- wdc: Fix strncpy warning (FATE#326925)
  + 0081-wdc-Fix-strncpy-warning.patch
- Refactor plugins in a file hierarchy (FATE#326925)
  + 0082-Refactor-plugins-in-a-file-hierarchy.patch
- nvme-cli: fix sanitize status endianness (FATE#326925)
  + 0083-nvme-cli-fix-sanitize-status-endianness.patch
- nvme-cli: fix ana-log endianness (FATE#326925)
  + 0084-nvme-cli-fix-ana-log-endianness.patch
- wdc: Use const string for suffix (FATE#326925)
  + 0085-wdc-Use-const-string-for-suffix.patch
- nvme-cli:fix a typo in SELF-TEST log (FATE#326925)
  + 0086-nvme-cli-fix-a-typo-in-SELF-TEST-log.patch
- nvme-cli: fix a typo (FATE#326925)
  + 0087-nvme-cli-fix-a-typo.patch
- nvme-cli: fix array len to hold string of size 4 (FATE#326925)
  + 0088-nvme-cli-fix-array-len-to-hold-string-of-size-4.patch
- nvme-cli: fix endianness for the structure field (FATE#326925)
  + 0089-nvme-cli-fix-endianness-for-the-structure-field.patch
- nvme: Handle supported capabilities result for get features (FATE#326925)
  + 0090-nvme-Handle-supported-capabilities-result-for-get-fe.patch
- connect-all: special treatment to EALREADY afetr write to (FATE#326925)
  + 0091-connect-all-special-treatment-to-EALREADY-afetr-writ.patch
- Added zsh completion installation (FATE#326925)
  + 0092-Added-zsh-completion-installation.patch
- nvme-cli: fix a typo (FATE#326925)
  + 0093-nvme-cli-fix-a-typo.patch
- nvme: fixup ANA group descriptor offset (FATE#326925)
  + 0094-nvme-fixup-ANA-group-descriptor-offset.patch
- nvme: introduce get_nvme_ctrl_attr() (FATE#326925)
  + 0095-nvme-introduce-get_nvme_ctrl_attr.patch
- nvme: print out controller state for 'list-subsys' (FATE#326925)
  + 0096-nvme-print-out-controller-state-for-list-subsys.patch
- nvme-list-subsys: Add device name argument and print out ANA (FATE#326925)
  + 0097-nvme-list-subsys-Add-device-name-argument-and-print-.patch
- list-subsys: Preserve line breaks and spaces (FATE#326925)
  + 0098-list-subsys-Preserve-line-breaks-and-spaces.patch
- Regen documentation (FATE#326925)
  + 0099-Regen-documentation.patch
- In json output, if the commands add zero length string, it (FATE#326123)
  + 0100-In-json-output-if-the-commands-add-zero-length-strin.patch
- Fix printing of large ANAGRPID values (FATE#326123)
  + 0101-Fix-printing-of-large-ANAGRPID-values.patch
- micron-nvme: Replace direct use of ioctl (FATE#326123)
  + 0102-micron-nvme-Replace-direct-use-of-ioctl.patch
- Fix printing of large ANAGRPID values (FATE#326123)
  + 0103-Fix-printing-of-large-ANAGRPID-values.patch
- Fix typos in docs (FATE#326123)
  + 0104-Fix-typos-in-docs.patch
- Fix typos in tests and utils (FATE#326123)
  + 0105-Fix-typos-in-tests-and-utils.patch
- fabrics: support fabrics sq flow control disable (FATE#326123)
  + 0106-fabrics-support-fabrics-sq-flow-control-disable.patch
- fabrics: use trtype_str when parsing a discovery log entry (FATE#326123)
  + 0107-fabrics-use-trtype_str-when-parsing-a-discovery-log-.patch
- nvme: Add TCP transport (FATE#326123)
  + 0108-nvme-Add-TCP-transport.patch
- fabrics: add tcp port tsas decoding (FATE#326123)
  + 0109-fabrics-add-tcp-port-tsas-decoding.patch
- fabrics: add transport header and data digest (FATE#326123)
  + 0110-fabrics-add-transport-header-and-data-digest.patch
- nvme-ioctl: clear rae for discovery log pages (FATE#326123)
  + 0111-nvme-ioctl-clear-rae-for-discovery-log-pages.patch
- Added support for virtualization-management command (FATE#326123)
  + 0112-Added-support-for-virtualization-management-command.patch
- nvme-cli: Don't print result on passthru error (FATE#326123)
  + 0113-nvme-cli-Don-t-print-result-on-passthru-error.patch
- nvme-cli: readme: fix typo in Alpine distro support (FATE#326123)
  + 0114-nvme-cli-readme-fix-typo-in-Alpine-distro-support.patch
- Added gentoo to README.md (FATE#326123)
  + 0115-Added-gentoo-to-README.md.patch
- fabrics: pass in number of write queues (FATE#326123)
  + 0116-fabrics-pass-in-number-of-write-queues.patch
- fabrics: pass in number of polling queues (FATE#326123)
  + 0117-fabrics-pass-in-number-of-polling-queues.patch
- Update documentation (FATE#326123)
  + 0118-Update-documentation.patch
- README: update Arch Linux install instructions (FATE#326123)
  + 0119-README-update-Arch-Linux-install-instructions.patch
- fabrics: allow nr_io/write/poll_queues and queue size to (FATE#326123)
  + 0120-fabrics-allow-nr_io-write-poll_queues-and-queue-size.patch
- nvme: Adding a block size selector to format (FATE#326123)
  + 0121-nvme-Adding-a-block-size-selector-to-format.patch
- nvme: Regenerate documentation (FATE#326123)
  + 0122-nvme-Regenerate-documentation.patch
- timeout option added to ns_create/delete (#440) (FATE#326123)
  + 0123-timeout-option-added-to-ns_create-delete-440.patch
- nvme: Remove duplicate error message (FATE#326123)
  + 0124-nvme-Remove-duplicate-error-message.patch
* Tue Oct 16 2018 jthumshirn@suse.com
- Update to version v1.6 (FATE#326139, FATE#326434, FATE#326558):
  * Release 1.6
  * lightnvm: fix type coercion
  * fix reservation report 0's based dword count
  * nvme.c, list_ns: use le32_to_cpu in display
  * nvme-cli: adjust memset size for data buffer in submit_io
  * fabrics: omit newline character when reading nvme host nqn
  * fabrics: fail early if argconfig_parse failed
  * nvme-cli: print firmware activation notices support bit to id_ctrl
  * nvme-cli: add support of RAE
  * Add a single get-property command for NVMeOF.
  * nvme-ioctl.c : nvme_get_properties(): fix 64bit offset advance
  * nvme-cli: add support for DLFEAT
  * intel: fix latency stats printing
  * Update doc
  * nvme-cli: add changed-ns-list-log documentation
  * nvme-cli: add changed log ns support
  * NVMe-CLI Fix id-ns fpi field when Human Readable option selected.
  * Fix format specifier for 32-bit
  * Fix json output of 128-bit numbers
  * Replace host-gen telemetry short-option 'h' with 'g'
  * Add man pages for new device self test commands
  * Updating version to 1.1
  * nvme-cli: Implement printing get NOPSC feature
  * nvme-cli: Implement printing the get Keep Alive Timer feature
  * nvme-cli: Implement printing the get host controlled thermal management feature.
  * nvme-cli: Implement printing the get timestamp feature.
  * Adding ppc big endian support
  * Revert "nvme-cli: Wait for device file if not present after successful add_ctrl"
  * Revert "nvme-cli: Add ioctl retry support for "connect-all""
  * nvme-cli: fix compilation error
  * Updatign the plugin version
  * refactored some strings
  * Removed Duplicate commands.
  * Initial checkin for Seagate Plugin
  * nvme-cli: update the document for id-nvmset subcommand
  * nvme-cli: update new fields in id-ns subcommand
  * nvme-cli: add support for id-nvmset subcommand
  * Wrote man page for telemetry
  * nvme-cli: Implemented Device self test and log.
  * Add user parameter to specify data area region from telemetry log
  * Regenerate man pages
  * Documentation: allow to format with asciidoctor
  * Documentation: fix title markers
  * fabrics: add ctrl-loss-tmo to connect-all
  * nvme-cli: Modify Get Features-Asynchronous Event Configuration
  * Add open-channel 2.0 identify support
  * nvme-cli: fix show command typo
  * nvme-cli: Fix build breaks for GCC 8.1 Signed-off-by: Alexey Timofeyev <alexey.timofeyev@sk.com>
  * Add nvme id-ns command test
  * Add nvme id-ctrl command test
  * Add nvme fw-log commmand test
  * Add support for Micron plugin
  * nvme-cli: fix get_nsid() return value check
  * nvme-cli: allow block device for delete-ns
  * nvme-cli: Add ioctl retry support for "connect-all"
  * nvme-cli: Wait for device file if not present after successful add_ctrl
  * nvme-cli: show partial results if controller fails during list and list-subsys
  * fabrics: add option to supply keep-alive-timeout for connect-all
  * nvme-cli: fix perror when blkdev not given when get-ns-id
  * Fixes for log page access.
  * nvme-cli: make it return 0 in case of non-fabric for show-regs
  * Regenrate documentation
  * Documentation: add manpage entry for connect's --ctrl-loss-tmo setting
  * nvme-cli: fix leak in endurance_log command
  * nvme-cli: fix seg_fault by cmd options in endurance_log
  * Remove error print for telemetry log arg parse
  * Fix intel media wear json output
  * Use fixed-width integer types for long suffixed parameters
  * Add toshiba plugin to makefile rules.
  * Add toshiba plugin code and command documentation.
  * nvme-cli: Add friendly status messages
  * nvme-cli: correct spelling of discovery
  * get-log: Make log identifier a required parameter
  * nvme-cli: fabrics: Fix passing "host_traddr" for all transports
  * Log error incase of failure in get_nvme_subsystem_info()
  * Fix double free in list_subsys
  * Fix parameter descriptions
  * Add remaining fields from NVM Sets
  * Don't print non-existent command line options
  * Fixed a bug where cdw11 was being overwritten by cdw12
  * Regenerate documentation
  * Add manpage for endurance log
  * nvme-cli: fix typo in 'disconnect' docs
  * Fix fabrics property commands
  * Fix endianess in WDC plugin.
  * Ignore cscope files
  * Add read-recover level feature decoding
  * Add support for NVMe Sets log page
  * Add support for decoding IO Determinism features
  * Add decoding for new controller attributes
  * Update makefile dependencies
  * nvme-cli: add netapp smdevices man page
  * nvme-cli: add NetApp plugin
  * Fix freeing wrong address
  * nvme-cli: make it use NVME_IDENTIFY_DATA_SIZE
  * nvme-cli: adjust json print according to uint format
  * nvme-cli: add helper for sanitize command
  * nvme-cli: telemetry-log add controller initiated log gathering
  * flush: Use device NSID if issuing through block device
  * NVMe-CLI Fix fw_log Command json output
  * nvme-cli: fix typo in Intel SMART json output
  * nvme-cli: update documentations to sync up with subcommands
  * nvme-cli: convert iekey into a no_argument parameter
  * nvme-cli: make return negative value in nvme_get_nsid() when not blkdev
  * nvme-cli: move print-function to nvme-print
  * nvme-cli: fix leaks in subcommands
  * nvme-cli: add print for command name to effects-log
  * nvme-cli: make it have bpid in cdw10 for fw-commit
  * nvme-cli: add command specific field to json output of error-log
  * nvme-cli: Fixed incosistency of error handling in intel plugin Signed-off-by: Oleksii Timofieiev <tim.oleksii@gmail.com>
  * Use '-' for compounded word telemetry-log subcommand
  * Use NSID all for error log
  * nvme-cli: Implement nvme_get_log13
  * nvme-cli: handle long commands in help message by adjusting minimal padding Signed-off-by: Oleksii Timofieiev <tim.oleksii@gmail.com>
  * nvme-cli: wdc: Removed superfluous output in WDC plugin
  * NVMe-CLI WDC-Plugin Update drive essentials code with review comments.
  * nvme-cli: Add support of unsigned long long to json routines Signed-off-by: Oleksii Timofieiev <tim.oleksii@gmail.com>
  * NVMe-CLI WDC-Plugin Add clear-pcie-corr documentation.
  * NVMe-CLI WDC-Plugin Add clear-pcie-corr command
  * NVMe-CLI WDC-Plugin Add drive-essentials documentation
  * NVMe-CLI WDC-Plugin Add drive-essentials command
  * nvme-cli: memblaze: add error return after parse_and_open()
  * nvme-cli: memblaze: fix memory leak in memblaze-nvme.c
  * nvme-cli: Implement get_telemetry_log from 1.3 spec
  * nvme/vendor: Add get log LSP/LSO fields from 1.3 spec
  * nvme-cli: lnvm: Make it return error status when argconfig_parse fails
  * nvme-cli: fix memory leak in passthru()
  * nvme-cli: wdc: fix mismatch in document for smart-add-log
  * nvme-cli: wdc: add const to descriptions
  * nvme-cli: fix memory leak in dir_receive()
  * nvme-cli: fix memory leak in sec_recv()
  * nvme-cli: fix memory leak in dir_send()
  * nvme-cli: fix memory leak in sec_send()
  * nvme-cli: fix memory leak in set_feature()
  * nvme-cli: fix memory leak in fw_download()
  * nvme-cli: fix memory leak in ns_descs()
  * nvme-cli: fix memory leak in list_ctrl()
  * nvme-cli: add error handling for a failure of malloc
  * nvme-cli: tests: fix typo in get_feature_test
  * nvme-cli: tests: remove nsid parameter in a testcase of error-log
  * nvme-cli: update documentation of effects-log
  * nvme-cli: add support for options to effects-log subcommand
  * nvme-cli: intel: add const to descriptions of subcommand option
  * nvme-cli: intel: add check for fd after open to intel commands
  * nvme-cli: intel: fix smart-log-add documentation
  * lightnvm: enable to set OP on target creation
  * nvme-cli: intel: update smart-log-add command documentation
  * nvme-cli: update error-log documentation
  * nvme-cli: lnvm: add human-readable print format to ns-id subcommand
  * nvme-cli: lnvm: add check for fd after open operation
  * nvme-cli: lnvm: remove unnecessary force parameter of ns-id in lnvm
  * nvme-cli: lnvm: add whitespace between words in a description
  * nvme-cli: add BPS bit field to CAP controller register
  * Update subcommand alias description in README.md
  * nvme-cli: add support for json output format of sanitize-log command
  * nvme-cli: Remove unnecessary nsid field in error-log
  * nvme-cli: add print for command specific info field of error log page
  * nvme-cli: update print for sanitize-log command with output-format
  * nvme-cli: make sanitize description const
  * Fix verbose decoding for coalescing aggregation time
  * Allow hierarchy of similiarly named plugins
  Drop:
  - 0001-nvme-cli-add-NetApp-plugin.patch
  - 0002-nvme-cli-add-netapp-smdevices-man-page.patch
  - 0003-get-log-Make-log-identifier-a-required-parameter.patch
  - 0004-Documentation-add-manpage-entry-for-connect-s-ctrl-l.patch
  - 0005-fabrics-add-option-to-supply-keep-alive-timeout-for.patch
  - 0006-fabrics-add-ctrl-loss-tmo-to-connect-all.patch
  - 0007-nvme-vendor-Add-get-log-LSP-LSO-fields-from-1.3-spec.patch
  - 0008-nvme-cli-Implement-nvme_get_log13.patch
  - 0009-nvme-cli-Add-support-of-unsigned-long-long-to-json-r.patch
  - 0010-nvme-cli-add-support-of-RAE.patch
  - 0011-nvme-cli-add-minimal-ana-log-page-support.patch
  - 0012-nvme-cli-add-ana-log-documentation.patch
  - 0013-nvme-discover-sanitize-options.patch
  - 0014-Fix-double-free-in-list_subsys.patch
  - 0015-Log-error-incase-of-failure-in-get_nvme_subsystem_in.patch
  - 0016-nvme-cli-move-print-function-to-nvme-print.patch
  - 0017-nvme-cli-show-partial-results-if-controller-fails-du.patch
  - 0018-nvme-list-subsys-Add-device-name-argument-and-print-.patch
  - 0019-nvme-discover-Retry-discovery-log-if-the-generation-.patch
  - 0020-nvme-cli-fabrics-Fix-passing-host_traddr-for-all-tra.patch
  - 0021-fabrics-write-ctrl_loss_tmo-to-fabrics-device-on-con.patch
  - 0022-fabrics-write-keep-alive-timeout-to-fabrics-device-o.patch
* Fri Aug 10 2018 hare@suse.de
- nvme-discover: Retry discovery log if the generation counter changes
  (bsc#1087848)
  + 0019-nvme-discover-Retry-discovery-log-if-the-generation-.patch
- nvme-fabrics: Fix passing "host_traddr" for all transports (bsc#1084379)
  + 0020-nvme-cli-fabrics-Fix-passing-host_traddr-for-all-tra.patch
- fabrics: write ctrl_loss_tmo to fabrics device on connect (bsc#1084379)
  + 0021-fabrics-write-ctrl_loss_tmo-to-fabrics-device-on-con.patch
- fabrics: write keep-alive-timeout to fabrics device on connect (bsc#1090568)
  + 0022-fabrics-write-keep-alive-timeout-to-fabrics-device-o.patch
* Tue Aug  7 2018 hare@suse.de
- nvme-vendor: Add get_log LSP & LSO fields from 1.3 spec
  (bsc#1099018)
  + 0007-nvme-vendor-Add-get-log-LSP-LSO-fields-from-1.3-spec.patch
- nvme-cli: Implement nvme_get_log13 (bsc#1099018)
  + 0008-nvme-cli-Implement-nvme_get_log13.patch
- nvme-cli: Add support of unsigned long long to json (bsc#1099018)
  + 0009-nvme-cli-Add-support-of-unsigned-long-long-to-json-r.patch
- nvme-cli: add support of RAE (bsc#1099018)
  + 0010-nvme-cli-add-support-of-RAE.patch
- nvme-cli: add minimal ana-log page support (bsc#1099018)
  + 0011-nvme-cli-add-minimal-ana-log-page-support.patch
- nvme-cli: add ana_log documentation (bsc#1099018)
  + 0012-nvme-cli-add-ana-log-documentation.patch
- nvme-discover: sanitize options
  + 0013-nvme-discover-sanitize-options.patch
- Fix double free in list_subsys
  + 0014-Fix-double-free-in-list_subsys.patch (bsc#1099018)
- Log error in case of failure in get_nvme_subsystem (bsc#1099018)
  + 0015-Log-error-incase-of-failure-in-get_nvme_subsystem_in.patch
- nvme-cli: move print function to nvme-print.c (bsc#1099018)
  + 0016-nvme-cli-move-print-function-to-nvme-print.patch
- nvme-cli: show partial results if controller fails (bsc#1099018)
  + 0017-nvme-cli-show-partial-results-if-controller-fails-du.patch
- nvme-list-subsys: Add device name argument and print ANA state
  (bsc#1099018)
  + 0018-nvme-list-subsys-Add-device-name-argument-and-print-.patch
* Thu Jun  7 2018 jthumshirn@suse.com
- Add ctrl-loss-tmo to connect-all command (bsc#1084379)
  + 0006-fabrics-add-ctrl-loss-tmo-to-connect-all.patch
* Wed May  2 2018 jthumshirn@suse.com
- Add keep-alive-tmo option to connect-all command (bsc#1090568)
  + 0005-fabrics-add-option-to-supply-keep-alive-timeout-for.patch
* Thu Apr 12 2018 jthumshirn@suse.com
- Add ctrl-loss-tmo option to fabrics connect manpage (bsc#1084379)
  + 0004-Documentation-add-manpage-entry-for-connect-s-ctrl-l.patch
* Wed Apr  4 2018 jthumshirn@suse.com
- Make log identifier a required parameter (bsc#1086240)
  + 0003-get-log-Make-log-identifier-a-required-parameter.patch
* Tue Feb 13 2018 jthumshirn@suse.com
- Add NetApp vendor plugin (bsc#1080672)
  + 0001-nvme-cli-add-NetApp-plugin.patch
  + 0002-nvme-cli-add-netapp-smdevices-man-page.patch
* Wed Jan 10 2018 jthumshirn@suse.com
- Update to version v1.5 (FATE#322735):
  * Remove upstreamed patches:
  - 0001-nvme-Introduce-new-list-subsys-command.patch
  - 0009-fabrics-also-set-queue_size-and-nr_io_queues-on-conn.patch
  * fabrics: also set queue_size and nr_io_queues on connect-all connects
  * nvme-cli: add duplicate_connect parameter support
  * nvme-cli : wdc-plugin Add support for WDC SN100 and SN200 devices.
  * Add AEN decoder helper to get-log
  * Regen documentation
  * Add Nix(OS) install instructions to the README
  * Fix the Markdown code for the Alpine install instructions
  * nvme-cli: make address print format more human-readable
  * intel-nvme: Fix compiler errors and warnings
  * Include sizing data in json output that's already included in the non-json results.
  * Cleanup variable definitions
  * Add command effects log page
  * Increase default format timeout
  * Revert "nvme-cli: add duplicate_connect parameter support"
  * nvme-cli: add duplicate_connect parameter support
  * nvme-cli: fix wrong bitmask in number of rpmb units.
  * nvme-cli: make command description const
  * nvme/id-ns: do not try to get namespace id from non-block device.
  * Fix typo in previous commit
  * Fix long suffix parse on 32-bit machines
  * Nitpicked a printing alignment issue with the id-ns vendor specific field
  * Avoid unnecessary abbreviation.
  * nvme/flush: explicitely close file descriptor
  * Fix memory leak
  * Add 'DEAC' support to write-zeroes command
  * Rebuild documentation
  * nvme-cli: resync nvme.h with the kernel's
  * NVMe-CLI : WDC-Plugin Updated Smart Log Command
  * NVMe-CLI : WDC-Plugin Documentation for Updated Smart Log Command
  * Regenerate documentation
  * nvme-cli: update show_registers_cc() to use nvme.h
  * nvme-cli: replace values of all namespaces with NVME_NSID_ALL
  * nvme-cli: add prints for new HMB identify fields of TP 4002
  * Update get-feature help text
  * Improve code alignment on intel plugin
  * Update intel internal log man page.
  * nvme-cli/intel: Return if arg parsing returns error
  * nvme: add options for write command directives
  * Update documentation
  * Updated the human readable printing for the SGLS field in the id-ctrl command to be compliant with NVMe 1.3
  * nvme: Introduce new 'list-subsys' command
  * nvme-cli: add support to get properties for NVMe over Fabric
  * nvme-cli: support to set the property for NVMe over Fabric
  * Reorder command list
  * Documentation fixes
  * nvme-cli: add support alias command with Firmware Activate
  * nvme-cli: update Firmware Commit with boot partition feature
  * nvme-cli: add command specific status of Firmware Commit
  * Update documentation to use aliases
  * nvme-cli: add prints of boot partition feature to show-regs
  * nvme-cli: Fix small mem leak.
  * Release v1.5
* Thu Dec 14 2017 jthumshirn@suse.com
- Add list-subs subcommand (bsc#1072813)
  + 0001-nvme-Introduce-new-list-subsys-command.patch
* Tue Oct 24 2017 jengelh@inai.de
- Update descriptions.
* Wed Oct 18 2017 jthumshirn@suse.com
- Update to version v1.4 (FATE#322735):
  * Fixup Security send/recv to read data from disk
  * Unbreak RPM build after bash completion files were moved in 7e4c7596
  * fabrics: Fix disconnect_by_device from disconnecting instance 0 on error
  * lightnvm: allow to init target on factory mode
  * Fixed problem with security-recv binary output not working correctly
  * nvme-cli: return 0 if disconnect operation with cfg.nqn successfully
  * Fix compile for 32-bit
  * nvme-cli: Fix build on aarch64-linux-android-4.9
  * nvme-cli: Huawei plug-in.
  * nvme-print: Fix line spacing on -H option
  * id-ctrl: remove new lines from json output
  * nvme-list: print empty lists when no devices are present
  * fabrics: add option to override drivers queue depth
  * nvme-cli: nvme-intel implement json output for smart-log
  * nvme-cli: Add parsing support for noiob
  * Fix potential device string truncation
  * fabrics: add option to override drivers queue depth also for connect-all command
  * Regenerate man-pages
  * Release v1.3
  * nvme-print: Free only top-level json objects
  * fix use-after-free in pci.ids parsing
  * nvme-cli: add fields into identify controller data structure
  * nvme-cli: show more fields for id-ctrl
  * nvme-cli: id-ctrl: display additional fields
  * Show help when no or an invalid device is given
  * nvme-cli: add id-ctrl for nvme-huawei plug-in.
  * Fix spelling errors
  * fabrics: add hostid option to connect command
  * nvme-cli: add ns-descs subcommand
  * nvme-cli: Get Feature support for Extended Host Id
  * nvme-cli: Fix typo in Intel plugin and improve generic help text
  * Implement Intel Vendor specific logs
  * nvme-cli: add thermal management fields for smart-log
  * nvme-cli: add temperature sensor fields in json_smart_log
  * nvme-cli: add output-format discription for smart-log
  * Formatting update
  * Regenerate documentation
  * nvme-cli: add error message for nvme list.
  * Fix typo of flbas in nvme_create_max_ns_test
  * Show help for get-ns-id
  * Show help for nvme reset and subsystem-reset
  * nvme-cli: Extended Data Structure in resv-report
  * Update docs
  * resync nvme.h with the kernel nvme.h
  * nvme-cli : add support for sanitize command.
  * nvme-cli : add sanitize command documentation.
  * nvme-cli : add support for retrieving sanitize log.
  * nvme-cli : add sanitize-log command documentation.
  * fix build without libuuid
  * nvme-cli : wdc-plug-in : return on invalid input device.
  * nvme-cli : only print help text and return for nvme list -h option.
  * nvme-cli/list-ns: fix identifying active or allocated namespaces list
  * Fixed get_internal_log to parse the entire nlog and allow selection of specific regions to be parsed.
  * NVMe-CLI Fix Sanitize Command Parameter Types
  * Fix app tag and mask setting
  * Fix app tag field sizes
  * nvme-cli/list: fix when nvme device can not be open
  * nvme-cli/list: change fd returned by open operation from unsigned to signed.
  * Makefile: allow linker override for cross uuid test
  * nvme-cli: fix connecting failure due to invalid uuid format of hostid
  * nvme-cli/fabrics: Add ctrl-loss-tmo param to connect cmd
  * Fixing macro definitions to avoid issues when these are used in expressions
  * nvme-cli: add nvme directive command support
  * nvme-cli: add documentation for directive commands
  * fix for issue 219, show-regs reports AQA.ACQS and AQA.ASQS as bytes
  * nvme-cli: Fix nvme ns desc
  * new bit fields (6, 7, and 8) for OACS from NVMe rev 1.3
  * added new bit field (6) to ONCS from NVMe rev 1.3
  * nvme-cli: Describe action 3 of nvme activate
  * nvme-cli: generate spec-compliant UUID NQNs
  * NVMe-CLI Fixed Status Code check for reset type on fw-activate.
  * Added handling for temperature threshold values below 0C(273K) and removed buffer check for human readable output as Temperature threshold feature does not use Memory Buffer for Attributes
  * Update nvme.c
  * nvme-cli : Add Namespace Rescan Command
  * nvme-cli : Add man documentation files for ns-rescan command.
  * Version 1.4 Release
  * Drop upstream patches:
  - 0001-fabrics-add-option-to-override-drivers-queue-depth.patch
  - 0002-fabrics-add-option-to-override-drivers-queue-depth-a.patch
  - add-missing-nvme_id_crtl-fileds.patch
  - 0003-nvme-cli-show-more-fields-for-id-ctrl.patch
  - 0004-nvme-cli-id-ctrl-display-additional-fields.patch
  - 0005-nvme-cli-add-ns-descs-subcommand.patch
  - 0006-fabrics-add-hostid-option-to-connect-command.patch
  - 0007-nvme-cli-fix-connecting-failure-due-to-invalid-uuid-format.patch
  - 0008-nvme-cli-generate-spec-compliant-uuid-nqns.patch
* Tue Oct 17 2017 jthumshirn@suse.com
- allow override queue depth and nr io queues on connect-all (bsc#1063462)
  + 0009-fabrics-also-set-queue_size-and-nr_io_queues-on-conn.patch
* Thu Sep  7 2017 jthumshirn@suse.com
- Generate Spec compliant UUID NQNs (bsc#1057498)
  + 0008-nvme-cli-generate-spec-compliant-uuid-nqns.patch
* Thu Aug 31 2017 jthumshirn@suse.com
- Fix hostid parsing (bsc#1049272)
  + 0007-nvme-cli-fix-connecting-failure-due-to-invalid-uuid-format.patch
* Fri Jun 30 2017 jthumshirn@suse.com
- Add hostid option to connect command (bsc#1045293)
  + 0006-fabrics-add-hostid-option-to-connect-command.patch
* Mon Jun 26 2017 jthumshirn@suse.com
- Create nvme files and directories in /etc/nvme (bsc#1045931 )
* Mon Jun 26 2017 jthumshirn@suse.com
- Provide nvme ns-descs subcommand (bsc#1038235)
  + 0005-nvme-cli-add-ns-descs-subcommand.patch
* Fri Jun 16 2017 jthumshirn@suse.com
-  Also re-build documentation on each build (bsc#1037297)
* Wed Jun 14 2017 jthumshirn@suse.com
- Add NVMe over Fabrics specific id-ctrl fields (bsc#1037293)
  + add-missing-nvme_id_crtl-fileds.patch
  + 0003-nvme-cli-show-more-fields-for-id-ctrl.patch
  + 0004-nvme-cli-id-ctrl-display-additional-fields.patch
* Fri May 12 2017 jthumshirn@suse.com
- Add possibility to change queue depth at connect time (bsc#1037297)
  + 0001-fabrics-add-option-to-override-drivers-queue-depth.patch
  + 0002-fabrics-add-option-to-override-drivers-queue-depth-a.patch
* Mon Apr 24 2017 jthumshirn@suse.com
- Update to version v1.2 (FATE#322735 ,bsc#1033410):
  * Include endian.h for byte/host order functions
  * nvme-cli: Add nvme hostnqn generation option
  * nvme.spec/debian: Auto generate host nqn as part of install
  * Documentation: Add entry for gen-hostnqn
  * Regenerate Documentation
  * Fix read/write man pages
  * get-features: Don't try to read the data buffer for sel == 3
  * Documentation: fix location of device reset
  * Regen documentation
  * Remove debian/ directory
  * Remove pyc files generated by 'make test'
  * Moving the bash completion files to the standard
  * lightnvm: default to -1 on lun begin and end
  * nvme-cli: fabrics: Fix to pass "host_traddr" to the kernel driver.
  * nvme-cli: id-ctrl: Fix memory leak for JSON.
  * nvme-cli: id-ns: Fix memory leak for JSON.
  * nvme-cli: error-log: Fix memory leak for JSON.
  * nvme-cli: resv-report: Fix memory leak.
  * nvme-cli: smart-log: Fix memory leak for JSON.
  * nvme-cli: fw-log: Fix memory leak for JSON.
  * nvme-cli: json_add_smart_log(): Fix memory leak for JSON.
  * nvme-cli: smart-log: Allow negative values for temp sensors.
  * Don't print unimplemented sensor
  * Build without uuid
  * get-ns-id: Exit when no device provided.
  * nvme-cli: id-ctrl: Add vendor fields in JSON id-ctrl.
  * nvme-cli: nvme.c: Allow plug-ins to access to output formats and helper.
  * nvme-cli: Western Digital/HGST plug-in.
  * nvme-cli: Western Digital/HGST plug-in documentation.
  * <linux/nvme.h>: Correct NVMF enum values to match NVMe-oF rev 1.0
  * fabrics: Handle space-padded TRSVCID and TRADDR fields
  * nvme-cli: bug-fix: use right file name for perror.
  * move show_intel_smart_log to intel-nvme.c
  * remove json_add_smart_log
  * remove nvme_intel_smart_log
  * move struct nvme_additional_smart_log to intel-nvme.c
  * nvme-cli/format: use existing LBAF if none requested
  * nvme-cli: Release v1.2
* Thu Mar  2 2017 jthumshirn@suse.com
-  Update to upstream release v1.1 (FATE#322735)
  * This fixes multiple compiler warnings for 32-bit and other environments
    from v1.0, adds more documentation to fabrics, removes the libudev
    dependency entirely from this project, adds a framework for unit testing
    devices, and fixes usage for user defined install paths
* Thu Sep 15 2016 jthumshirn@suse.com
- Update to upstream release v0.9
  - Remove merged remove-version-from-list.patch
  * New extensions, fabrics support, a bug fixes. The 'list' command
    is liberated from its udev dependency, and no longer requires
    CONFIG_IO_STRICT_DEVMEM be disabled.
* Wed Aug 31 2016 jthumshirn@suse.com
- Don't map controller registers in 'list' command (boo#986891)
  + remove-version-from-list.patch
* Tue Aug  9 2016 jthumshirn@suse.com
- Update to upstream release v0.8
  - Remove merged patch 0001-bash-completion-Remove-shebang-line.patch
  * Code re-organized to support new extensions. While these are called
    "plugins", they currently have to be built into the executable. Support
    for dynamically loadable plugins is under consideration.
  * LightNVM is added as a built-in plugin.
  * Intel vendor specific commands and structure decodings are supported
    in a new intel plugin.
  * Support for NVMe-over-Fabrics
  * New output format "json" for a subset of commands that decode returned
    structures.
  * Lots of various documentation and minor code fixes.
* Wed Jun  1 2016 jthumshirn@suse.com
- Update to upstream release v0.7
  + 0001-bash-completion-Remove-shebang-line.patch
  Keith writes:
    Just a few minor updates and documentation fixes. There is also a new
    option for passthrough commands that can be used to help detect data
    over/under run.
    Tagging a stable release so we can consider features that bring in other
    transports and third party extensions.
* Wed Apr 13 2016 jthumshirn@suse.com
- Exclude build on s390x (FATE#319560)
* Fri Mar 18 2016 jthumshirn@suse.com
- Update to upstream release v0.5
    The v0.4 breakage should all be resolved now. Tagging release
    v0.5, and back to stability.
* Wed Mar  2 2016 jthumshirn@suse.com
- Update to upstream release v0.4
* Mon Feb 15 2016 jthumshirn@suse.com
- Fix display of version number (boo#966740)
* Thu Feb 11 2016 jthumshirn@suse.com
- Initial packaging for openSUSE
